<?php

class Rss_Control_Admin {


	public function __construct( ) {

	}

	public function admin_menu(){
		add_options_page( RSS_CONTROL_NAME . ' How-To', RSS_CONTROL_NAME, 'manage_options', RSS_CONTROL_SLUG, [$this, 'howto_page'] );
	}

	public function plugin_action_links($links){
		$links[] = '<a href="'. esc_url( get_admin_url(null, 'options-general.php?page='.RSS_CONTROL_SLUG) ) .'">How to Use</a>';
		return $links;
    }

	public function howto_page(){
	?>
		<div class="wrap">
			<h1>How to use <?php echo RSS_CONTROL_NAME; ?></h1>
			<p><?php echo RSS_CONTROL_NAME; ?> is a simple plugin which allows you to control several aspects of your
				RSS feeds through the Feed URL. These work on all feed types including the main feed, category feeds, tag feeds, etc.
				Below is a list of options that are supported.  If you would like additional features added
				please visit <a href="https://pramadillo.com/feature-requests/" target="_blank">https://pramadillo.com/feature-requests/</a>
				and submit you request.
			</p>
			<hr>
			<h2>Example</h2>
			<p>
				<code><?php echo get_site_url(); ?>/feed/?cat=89&days_past=7&show_images=true&image_styles=border:4px; border-color:#000; float:left;</code>
				<br>
				The example above will show posts from category 89 from the past 7 days.  It will show featured images with a 4px black border floated to the left;
			</p>
			<h2>Options</h2>
			<h3>cat</h3>
			<p>This can be either a single category ID or a string of category ids that are separated by commas.  You can find out more at <a href="https://developer.wordpress.org/reference/classes/wp_query/#category-parameters" target="_blank">https://developer.wordpress.org/reference/classes/wp_query/#category-parameters</a>
			<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?cat=-3,10,22</code>
				<br>
				<small><em>The use of the NEGATIVE infront of the category ID says DO NOT INCLUDE posts from category 3</em></small>
			</p>
			<hr>
			<h3>category_not_in</h3>
			<p>This is an array of category IDs that you do NOT want to show in your feed.  You can find out more at <a href="https://developer.wordpress.org/reference/classes/wp_query/#category-parameters" target="_blank">https://developer.wordpress.org/reference/classes/wp_query/#category-parameters</a>
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?category_not_in=-3,10</code>
				<br>
				<small><em>Display posts that do not have any of the category ids 3 and 10</em></small>
			</p>
			<hr>

			<h3>tag</h3>
			<p>This can be either a single tag ID or a string of tag ids that are separated by commas.  You can find out more at <a href="https://developer.wordpress.org/reference/classes/wp_query/#tag-parameters" target="_blank">https://developer.wordpress.org/reference/classes/wp_query/#tag-parameters</a>
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?tag=-3,10,22</code>
				<br>
				<small><em>The use of the NEGATIVE infront of the tag ID says DO NOT INCLUDE posts from tag 3</em></small>
			</p>
			<hr>

			<h3>tag_not_in</h3>
			<p>This is an array of tags IDs that you do NOT want to show in your feed.  You can find out more at <a href="https://developer.wordpress.org/reference/classes/wp_query/#tag-parameters" target="_blank">https://developer.wordpress.org/reference/classes/wp_query/#tag-parameters</a>
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?tag_not_in=-3,10</code>
				<br>
				<small><em>Display posts that do not have any of the two tag ids 3 and 10</em></small>
			</p>
			<hr>
			<h3>offset</h3>
			<p>This is a number which you want to offset the feed by. You can find out more at <a href="https://developer.wordpress.org/reference/classes/wp_query/#pagination-parameters" target="_blank">https://developer.wordpress.org/reference/classes/wp_query/#pagination-parameters</a>
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?offset=3</code>
				<br>
				<small><em>This will skip the 3 latest posts and start the feed with post 4</em></small>
			</p>
			<hr>
			<h3>days_past</h3>
			<p>This allows you to have your RSS feed so posts from past X number of days in the past.
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?days_past=7</code>
				<br>
				<small><em>This will display the posts from the last 7 days in a feed.</em></small>
			</p>
			<hr>
			<h3>show_images</h3>
			<p>This allows you to display the featured image in the content of the RSS feed.
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?show_images=true</code>
				<br>
				<small><em>This will display featured image in the content of the RSS feed.  The default image size is 696x385</em></small>
			</p>
			<hr>
			<h3>image_width</h3>
			<p>This allows you to set the image width for the featured image
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?show_images=true&image_width=300</code>
				<br>
				<small><em>This will set the inline style of the image to have width: 300px;</em></small>
			</p>
			<hr>
			<h3>image_height</h3>
			<p>This allows you to set the image height for the featured image
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?show_images=true&image_height=300</code>
				<br>
				<small><em>This will set the inline style of the image to have height: 300px;</em></small>
			</p>
			<hr>
			<h3>image_size_unit</h3>
			<p>This allows you to set the image size unit for the featured image.  i.e. px, em, %, fr, etc
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?show_images=true&image_width=100&image_size_unit=%</code>
				<br>
				<small><em>This will set the inline style of the image to have a width of 100%</em></small>
			</p>
			<hr>
			<h3>image_styles</h3>
			<p>This allows you to set any additional image inline styles as you would like.  These come before the width & height.
				<br><br>
				<strong>Example: </strong>
				<code><?php echo get_site_url(); ?>/feed/?show_images=true&image_styles=border:4px; border-color:#000; float:left;</code>
				<br>
				<small><em>This will set the inline style of the image to have a a black border of 4px and floating the image to the left.</em></small>
			</p>

            <hr>
            <h3>excerpt_length</h3>
            <p>This allows you to control the length of the excerpt you have for the feed in number of WORDS
                <br><br>
                <strong>Example: </strong>
                <code><?php echo get_site_url(); ?>/feed/?excerpt_length=20</code>
                <br>
                <small><em>This will return all of the feed items with the content of only 20 words.</em></small>
            </p>

            <hr>
            <h3>excerpt_more_text</h3>
            <p>This allows you to set the character that appears when content is truncated.  Normally it is either [...] or ...
                <br><br>
                <strong>Example: </strong>
                <code><?php echo get_site_url(); ?>/feed/?excerpt_length=20&excerpt_more_text=%5B...Read%20More%5D</code>
                <br>
                <small><em>This will return all of the feed items with the content of only 20 words ending the content with [...Read More].</em></small>
            </p>
		</div>

	<?php
	}
}
