<?php

class Rss_Control_Public {

	protected $image_width;
	protected $image_height;
	protected $image_size_unit;
	protected $image_styles;


	public function __construct() {
		$this->image_width     = 696;
		$this->image_height    = 385;
		$this->image_size_unit = 'px';
		$this->image_styles    = null;
	}


	public function pre_get_posts( $query ) {
		if ( is_feed() ) {
			//We are explicitly setting the order to be date + title, because if articles have the exact date/time they
			// will be displayed in random order which will make it wonky when you apply an offset to query string
			$query->set( 'orderby', array( 'date' => 'DESC', 'title' => 'ASC' ) );

			if ( $this->is_set( 'days_past' ) ) {
				$query->set( 'date_query', array( array( 'after' => (int) $_GET['days_past'] . ' days ago', ) ) );
			}
			if ( $this->is_set( 'offset' ) ) {
				$query->set( 'offset', (int) $_GET['offset'] );
			}
			if ( $this->is_set( 'cat' ) ) {
				$query->set( 'cat', sanitize_text_field( $_GET['cat'] ) );
			}
			if ( $this->is_set( 'category_not_in' ) ) {
				$query->set( 'category__not_in', sanitize_text_field( $_GET['category_not_in'] ) );
			}

			if ( $this->is_set( 'tag' ) ) {
				$query->set( 'tag', sanitize_text_field( $_GET['tag'] ) );
			}

			if ( $this->is_set( 'tag_not_in' ) ) {
				$query->set( 'tag__not_in', sanitize_text_field( $_GET['tag_not_in'] ) );
			}

			if ( $this->is_set( 'excerpt_length' ) ) {
				add_filter( 'the_excerpt_rss', [ $this, 'trim_excerpt' ] );
				add_filter( 'the_content_feed', [ $this, 'trim_excerpt' ] );

			}

			if ( $this->is_set( 'show_images' ) ) {

				if ( $_GET['show_images'] === 'true' ) {

					if ( $this->is_set( 'image_width' ) ) {
						$this->set_width( $_GET['image_width'] );
					}

					if ( $this->is_set( 'image_height' ) ) {
						$this->set_height( $_GET['image_height'] );
					}

					if ( $this->is_set( 'image_size_unit' ) ) {
						$this->set_image_size_unit( $_GET['image_size_unit'] );
					}

					if ( $this->is_set( 'image_styles' ) ) {
						$this->set_image_styles( $_GET['image_styles'] );
					}

					add_filter( 'the_excerpt_rss', [ $this, 'add_thumbnail_to_feed' ] );
					add_filter( 'the_content_feed', [ $this, 'add_thumbnail_to_feed' ] );

				}

			}


		}


		return $query;
	}

	public function trim_excerpt( $content ) {
		$more = null;
		if ( $this->is_set( 'excerpt_more_text' ) ) {
			$more = sanitize_text_field( $_GET['excerpt_more_text'] );
		}

		return wp_trim_words( $content, (int) $_GET['excerpt_length'], $more );
	}

	public function add_thumbnail_to_feed( $content ) {
		global $post;
		$content = preg_replace( '/[[:cntrl:]]/', '', $content );

		if ( has_post_thumbnail( $post->ID ) ) {
			$content = '<img src="' . get_the_post_thumbnail_url( $post->ID, [
					$this->image_width,
					$this->image_height,
				] ) . '" style="' . $this->image_styles . ' width:' . $this->image_width . $this->image_size_unit . '; height:' . $this->image_height . $this->image_size_unit . '; border:0;">' . $content;
		}

		return $content;
	}


	protected function set_image_styles( $styles ) {
		if ( $styles != '' ) {
			$this->image_styles = sanitize_text_field( strtolower( $styles ) );
		}
	}

	protected function set_image_size_unit( $unit ) {
		if ( $unit != '' ) {
			$this->image_size_unit = sanitize_text_field( strtolower( $unit ) );
		}
	}

	protected function set_width( $width ) {
		if ( $width != '' ) {
			$this->image_width = (int) $width;
		}
	}

	protected function set_height( $height ) {
		if ( $height != '' ) {
			$this->image_height = (int) $height;
		}
	}

	protected function is_set( $var ) {
		if ( isset( $_GET[ $var ] ) && ! empty( $_GET[ $var ] ) ) {
			return true;
		}

		return false;
	}


}
